pub fn orb_elements(
planet: &Planet,
JD: f64,
) -> (f64, f64, f64, f64, f64, f64, f64, f64)Expand description
Computes a planet’s orbital elements, referred to the mean equinox of the date
Returns
(L, a, e, i, omega, pi, M, w)
L: Mean longitude | in radiansa: Semimajor axis of the orbit | in AUe: Eccentricity of the orbiti: Inclination of the plane of the orbit with the plane of the Earth’s ecliptic | in radiansomega: Longitude of the ascending node | in radians. An undefined value is returned forPlanet::Earth.pi: Longitude of the perihelion | in radiansM: Mean anomaly | in radiansw: Argument of the perihelion | in radians. An undefined value is returned forPlanet::Earth.
Arguments
planet: Any variant of PlanetJD: Julian (Ephemeris) day